@@ -13,8 +13,8 @@ const int MERGE_DELETE_UNDEF = 32;
 const int MERGE_COPY_SOURCE  = 64;
 const int MERGE_COPY         = MERGE_COPY_DEST | MERGE_COPY_SOURCE;
 
-HV* hash_merge (pTHX_ HV* dest, HV* source, IV flags);
+HV* hash_merge (pTHX_ HV* dest, HV* source, IV flags = 0);
 
-SV* merge (pTHX_ SV* dest, SV* source, IV flags);
+SV* merge (pTHX_ SV* dest, SV* source, IV flags = 0);
 
 }}
